# Minicheck

## Factcheck

Types:

```python
from bespokelabs.types.minicheck import FactcheckCreateResponse
```

Methods:

- <code title="post /v0/minicheck/factcheck">client.minicheck.factcheck.<a href="./src/bespokelabs/resources/minicheck/factcheck.py">create</a>(\*\*<a href="src/bespokelabs/types/minicheck/factcheck_create_params.py">params</a>) -> <a href="./src/bespokelabs/types/minicheck/factcheck_create_response.py">FactcheckCreateResponse</a></code>
